
#import <Foundation/Foundation.h>
#import <AppKit/AppKit.h>

@interface NSString(NSStringAdditions)

- (NSArray *)pathComponentsWithSeparator:(char)sepChar;

- (NSString *)stripLeadingTrailingSpaces;

/* change \ to / */
- (NSString *)unixString;

/* make the string safe as a bourne shell command */
- (NSString *)bourneString;

- (BOOL)containsString:(NSString *)aString 
	ignoreCase:(BOOL)caseflag
	isASCII:(BOOL)asciiFlag;
		// Returns YES if the receiver contains within it the pattern
		// given in 'aString'. If caseflag is YES case is not taken
		// into account in the compare. If asciiFlag is YES, a literal,
		// byte by byte comparison is done.

- (BOOL)containsString:(NSString *)aString;
		// calls containsString:ignoreCase:isASCII: assuming a case
		// sensitive, ascii comparison.

- (NSString *)stringToCharsInSet:(NSCharacterSet *)aSet;
		// Returns the string up to but not including the first 
		// occurance of a character from the specified set.  
		// An ASCII comparison is made. 
		// Returns nil if a character from the set is not found.
		
- (NSArray *)tokenizeStringWithDelimiters:(NSCharacterSet *)delimiters;
		// Separates the words in the receiver by the characters in
		// 'delimiters' and returns an array with each element
		// containing one token.
- (NSArray *)lineArray;
 		// calls tokenizeStringWithDelimiters with the newline to get
 		// separate lines in the array
- (NSArray *)tabArray;
- (NSArray *)semicolonArray;
- (NSArray *)barArray;
- (NSArray *)wordArray;

- (BOOL)isContainedIn:aString;
- (BOOL)isEqualToStringIgnoreCase:(NSString *)aString;
- (BOOL)includesPath:(NSString *)aPath;

- (Class)classValue;
- (SEL)selectorValue;

- (int)indexOfCharacter:(int)aChar startingAt:(int)startIndex;
- (int)indexOfCharacter:(int)aChar;

- (BOOL)isNotEmpty;
- (BOOL)isEmpty;

- (BOOL)isValidPathWithSeparator:(char)separator;
- (BOOL)isValidPath;

- (NSString *)reduceToLength:(float)w forFont:(NSFont *)aFont;

- (NSString *)stringByDeletingLastPathComponent:(char)sep;
- (NSString *)stringByAppendingPathComponent:(NSString *)aPath separator:(char)sep;
- (NSString *)lastPathComponent:(char)sep;

@end

