
/*  STDocumentClass.h written by Robert Vasvari, Oct 1994.
	This class is a generic document that has its own nibfile.
	The Document object comes with: name,path and window. Also,
	it implements some of the most basic document handling
	methods that most apps need.
 */

#import <AppKit/AppKit.h>
#import <Foundation/NSString.h>
#import <Foundation/NSDate.h>

@interface STDocumentClass:NSObject
{
	id window;
	NSString *documentName, *documentPath;
	int tag;
	NSCalendarDate *createTime, *lastModifyTime;
	BOOL isSaved;
}


/* ==== init section ==== */
+ newDocument;
- (NSString *)nibName;
- init;
- (void)awakeFromNib;

/* ==== access to instance variables ==== */
- window;
- (void)setWindowFrame:(NSRect)aFrame;
- (void)setCreateTime:(NSCalendarDate *)aTime;
- (NSCalendarDate *)createTime;
- (void)setLastModifyTime:(NSCalendarDate *)aTime;
- (NSCalendarDate *)lastModifyTime;
- (int)tag;
- (void)setTag:(int)aTag;
- (NSString *)documentName;
- (NSString *)documentPath;
- (void)setDocumentName:(NSString *)aName;
- (void)setDocumentPath:(NSString *)aPath;
- (void)getInspectorData:(NSString **)nm :(NSString **)pth :(int *)t :(NSCalendarDate **)ct :(NSCalendarDate **)lt;

/* ==== file handling ==== */
- (BOOL)openDocumentFile:(NSString *)aPath;
- (BOOL)readFromDict:(NSDictionary *)dict;
- (void)saveToDict:(NSMutableDictionary *)dict;
- (void)saveDocument;
- (void)saveDocumentAs:(NSString *)aPath;
- (NSString *)dictionaryPath;
- (void)saveDocumentTo:(NSString *)aPath;
- (void)setWindowTitle:(NSString *)aTitle;
- (void)modifiedSelf:sender;
- (BOOL)isSaved;

/* ==== Window delegate methods ==== */
- (void)windowDidBecomeKey:(NSNotification *)notification;
- (BOOL)windowShouldClose:(id)sender;
- (void)windowDidUpdate:(NSNotification *)notification;
- (void)windowDidResize:(NSNotification *)notification;

- (void)dealloc;
@end
